@@ -1,6 +1,8 @@
 // Copyright © SixtyFPS GmbH <info@slint-ui.com>
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-Slint-commercial
 
+// cSpell: ignore buildrs
+
 /*!
 # Slint
 
@@ -12,6 +14,7 @@ If you are already familiar with Slint, the following topics provide related inf
 
 ## Related topics
 
+ * [Examples and Recipes](docs::recipes)
  * [The `.slint` language reference](docs::langref)
  * [Builtin Elements](docs::builtin_elements)
  * [Widgets](docs::widgets)
@@ -68,11 +71,11 @@ build = "build.rs"
 edition = "2021"
 
 [dependencies]
-slint = "0.2.1"
+slint = "0.2.2"
 ...
 
 [build-dependencies]
-slint-build = "0.2.1"
+slint-build = "0.2.2"
 ```
 
 Use the API of the slint-build crate in the `build.rs` file:
@@ -242,7 +245,7 @@ pub use i_slint_core::graphics::{
     Brush, Color, Image, LoadImageError, Rgb8Pixel, Rgba8Pixel, RgbaColor, SharedPixelBuffer,
 };
 pub use i_slint_core::model::{
-    Model, ModelNotify, ModelPeer, ModelRc, ModelTracker, StandardListViewItem, VecModel,
+    Model, ModelExt, ModelNotify, ModelPeer, ModelRc, ModelTracker, StandardListViewItem, VecModel,
 };
 pub use i_slint_core::sharedvector::SharedVector;
 pub use i_slint_core::string::SharedString;
@@ -283,15 +286,15 @@ pub mod re_exports {
     pub use i_slint_core::callbacks::Callback;
     pub use i_slint_core::component::{
         free_component_item_graphics_resources, init_component_items, Component, ComponentRefPin,
-        ComponentVTable,
+        ComponentVTable, ComponentWeak, IndexRange,
     };
     pub use i_slint_core::graphics::*;
     pub use i_slint_core::input::{
         FocusEvent, InputEventResult, KeyEvent, KeyEventResult, KeyboardModifiers, MouseEvent,
     };
     pub use i_slint_core::item_tree::{
-        visit_item_tree, ItemTreeNode, ItemVisitorRefMut, ItemVisitorVTable, TraversalOrder,
-        VisitChildrenResult,
+        visit_item_tree, ItemTreeNode, ItemVisitorRefMut, ItemVisitorVTable, ItemWeak,
+        TraversalOrder, VisitChildrenResult,
     };
     pub use i_slint_core::items::*;
     pub use i_slint_core::layout::*;
@@ -301,6 +304,7 @@ pub mod re_exports {
     pub use i_slint_core::window::{Window, WindowHandleAccess, WindowRc};
     pub use i_slint_core::Color;
     pub use i_slint_core::ComponentVTable_static;
+    pub use i_slint_core::Coord;
     pub use i_slint_core::SharedString;
     pub use i_slint_core::SharedVector;
     pub use num_traits::float::Float;
@@ -547,7 +551,7 @@ macro_rules! include_modules {
 /// Helper type that helps checking that the generated code is generated for the right version
 #[doc(hidden)]
 #[allow(non_camel_case_types)]
-pub struct VersionCheck_0_2_1;
+pub struct VersionCheck_0_2_2;
 
 #[cfg(doctest)]
 mod compile_fail_tests;
